@@ -175,7 +175,9 @@ typedef enum
   GST_PHOTOGRAPHY_CAPS_APERTURE = (1 << 8),
   GST_PHOTOGRAPHY_CAPS_EXPOSURE = (1 << 9),
   GST_PHOTOGRAPHY_CAPS_SHAKE = (1 << 10),
-  GST_PHOTOGRAPHY_CAPS_NOISE_REDUCTION = (1 << 11)
+  GST_PHOTOGRAPHY_CAPS_NOISE_REDUCTION = (1 << 11),
+  GST_PHOTOGRAPHY_CAPS_FLICKER_REDUCTION = (1 << 12),
+  GST_PHOTOGRAPHY_CAPS_ALL = (~0)
 } GstPhotoCaps;
 
 typedef enum
